<?php

/*
Plugin Name: WP System Health
Version: 1.1.2
Plugin URI: http://www.code-styling.de/english/development/wordpress-plugin-wp-system-health-en
Description: Adds a comprehensive overview and analysis tool into your dashboard to get a single point information about PHP and WordPress internal states and configuration.
Author: Heiko Rabe
Author URI: http://www.code-styling.de/english/

License:
 ==============================================================================
 Copyright 2009 Heiko Rabe  (email : info@code-styling.de)

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
   Requirements:
 ==============================================================================
 This plugin requires WordPress >= 2.7 and PHP Interpreter >= 4.4.3

*/

if (!function_exists ('add_action')) {
	header('Status: 403 Forbidden');
	header('HTTP/1.1 403 Forbidden');
	exit();
}

class wpsh_plugin {
	function wpsh_plugin() {
		$this->__construct();
	}
	
	function __construct() {
		$this->theme_done = false;
		$this->gettext_default_done = false;
		$this->transports_available = array(
			'curl' => array( 'use' => false, 'name' => 'PHP libcurl', 'desc' => 'Allows you to connect and communicate to many different types of servers with many different types of protocols.'), 
			'streams' => array( 'use' => false, 'name' => 'PHP Streams API', 'desc' => 'Streams were introduced with PHP 4.3.0 as a way of generalizing file, network, data compression, and other operations which share a common set of functions and uses.'), 
			'fopen' => array( 'use' => false, 'name' => 'function fopen', 'desc' => 'Opens file or URL.'), 
			'fsockopen' => array( 'use' => false, 'name' => 'function fsockopen', 'desc' => 'Open Internet or Unix domain socket connection'), 
			'exthttp' => array( 'use' => false, 'name' => 'Built-in HTTP', 'desc' => 'It eases handling of HTTP URLs, dates, redirects, headers and messages and more.')
		);
		global $wpsh_boot_loader;
		if (get_class($wpsh_boot_loader) != 'wpsh_boot_loader') {
			require_once('boot-loader.php');
			$this->boot_loader = new wpsh_boot_loader();
		}
		else{
			$this->boot_loader = &$wpsh_boot_loader;
		}
		$this->boot_loader->pass_checkpoint_system_health();
		add_action('plugins_loaded', array(&$this, 'on_plugins_loaded'), 99999);
		add_action('setup_theme', array(&$this, 'on_setup_theme'), 99999);
		add_filter('gettext', array(&$this, 'on_gettext'), 99999, 2);
		add_action('init', array(&$this, 'on_init'), 99999);
		add_action('admin_init', array(&$this, 'on_admin_init'), 99999);
		add_filter('use_fsockopen_transport', array(&$this, 'on_use_fsockopen_transport'));
		add_filter('use_fopen_transport', array(&$this, 'on_use_fopen_transport'));
		add_filter('use_streams_transport', array(&$this, 'on_use_streams_transport'));
		add_filter('use_http_extension_transport', array(&$this, 'on_use_http_extension_transport'));
		add_filter('use_curl_transport', array(&$this, 'on_use_curl_transport'));
		$this->plugin_basename = plugin_basename(__FILE__);
		$active_plugins = get_option('active_plugins');
		if ($active_plugins[0] != $this->plugin_basename) {
			//force at least at next page load this plugin to be the first one loaded to show up the other plugins memory consume
			$reorder[] = $this->plugin_basename;
			foreach($active_plugins as $plugin) {
				if ($plugin != $this->plugin_basename)
					$reorder[] = $plugin;
			}
			update_option('active_plugins', $reorder);
		}
	}
	
	
	function on_use_fsockopen_transport($use) {
		$this->transports_available['fsockopen']['use'] = $use;
		return $use; //do not change
	}
	function on_use_fopen_transport($use) {
		$this->transports_available['fopen']['use'] = $use;
		return $use; //do not change
	}
	function on_use_streams_transport($use) {
		$this->transports_available['streams']['use'] = $use;
		return $use; //do not change
	}
	function on_use_http_extension_transport($use) {
		$this->transports_available['exthttp']['use'] = $use;
		return $use; //do not change
	}
	function on_use_curl_transport($use) {
		$this->transports_available['curl']['use'] = $use;
		return $use; //do not change
	}
	
	
	function on_plugins_loaded() {
		$this->boot_loader->pass_checkpoint_plugins_loaded();
	}
	
	function on_setup_theme() {
		$this->boot_loader->pass_checkpoint_setup_themes();
		$this->theme_done = true;
	}
	
	function on_gettext($trans, $org) {
		if ($this->gettext_default_done) return $trans;
		if ($org == 'M_Monday_initial') {
			$this->boot_loader->pass_checkpoint_gettext($org != $trans);
			$this->gettext_default_done = true;
		}
		return $trans;
	}
	
	function on_init() {
		$this->boot_loader->pass_checkpoint_init();
		$http = _wp_http_get_object(); //force collect of transports
	}
	
	function on_admin_init() {
		$this->boot_loader->pass_checkpoint_admin_init();
		if (current_user_can('level_10')) {
			add_action('wp_dashboard_setup', array (&$this, 'on_dashboard_setup'));
		}
	}
	
	function on_dashboard_setup() {
		wp_add_dashboard_widget( 'csp_boot_loader_dashboard', 'WordPress System Health', array (&$this, 'on_dashboard_widget') );
		wp_enqueue_script('jquery-ui-tabs');
		wp_enqueue_style('jquery-ui-tabs-wpsh-css', WP_PLUGIN_URL.'/'.dirname(plugin_basename(__file__)).'/ui.all.css');
	}
	
	function _echo_progress_bar($perc, $value, $desc, $low, $high){
		$color = ($perc <= $low ? '#21759B' : ($perc > $high ? 'red' : '#E66F00'));
	?>
		<div class="progressbar">
			<div class="widget" style="height:12px; border:1px solid #DDDDDD; background-color:#F9F9F9;width:100%; margin: 3px 0;">
				<div class="widget" style="width: <?php echo min($perc, 100.0) ?>%;height:100%;background-color:<?php echo $color; ?>!important;border-width:0px;text-shadow:0 1px 0 #000000;color:#FFFFFF;text-align:right;font-weight:bold;font-size:8px;margin-bottom:4px;"><div style="padding:0 6px; white-space:nowrap;word-wrap:normal!important;overflow: hidden;"><?php echo $perc; ?>&nbsp;%</div></div>
			</div>
		</div>
		<div style="margin-bottom:8px;"><small><strong><?php echo $value; ?></strong> | 
		<?php echo $desc; ?><small>
		</div>
	<?php
	}
	
	function _echo_checkpoint_row($checkpoint){
		foreach($checkpoint as $name => $data) :
		$perc = round($data['mem'] * 100.0 / $this->boot_loader->memory_limit, 2);
	?>
		<tr class="wpsh-sect-memory" style="display:none;">
			<td><?php echo $data['title']; ?><br/><small><i>(<?php echo $name; ?>)</i><small></td>
			<td width="100%">
				<?php $this->_echo_progress_bar($perc, (empty($data['mem']) ? '-n.a.-' : size_format($data['mem'], 2)), $data['desc'], 80, 95);	?>
			</td>
		</tr>
	<?php
		endforeach;
	}
	
	function on_dashboard_widget() {
		global $wp_version, $pagenow;
		$this->boot_loader->_pass_checkpoint($pagenow, 'Rendering Dashboard', 'Will be passed during generation of this Dashboard Overview.');
		?>
		<div id="wpsh-tabs" class="inside">
			<ul>
				<li><a href="#wpsh-overview">System</a></li>
				<li><a href="#wpsh-php">PHP</a></li>
				<li><a href="#wpsh-wordpress">WordPress</a></li>
				<li><a href="#wpsh-database">Database</a></li>
			</ul>
			<div id="wpsh-overview">
				<table width="100%" class="fixed widefat" cellspacing="8px"  style="border-style: none;">
					<tr><td width="110px;"><b>Server Setup:</b></td>
						<td><a class="wpsh-toggle-section" id="wpsh-sect-0" href="#wpsh-checkpoint"><span>Details &raquo;</span><span style="display:none">&laquo; Simple</span></a></td>
					</tr>
					<tr><td>OS Type</td><td><b><?php echo php_uname(); ?></b></td></tr>
					<tr><td>PHP Version</td><td><b><?php echo PHP_VERSION; ?></b></td></tr>
					<tr class="wpsh-sect-0" style="display:none"><td>Zend Version</td><td><b><?php echo zend_version(); ?></b></td></tr>
					<tr class="wpsh-sect-0" style="display:none"><td>Platform</td><td><b><?php echo (PHP_INT_SIZE * 8).'Bit'; ?></b></td></tr>
					<tr class="wpsh-sect-0" style="display:none"><td>Loaded Extensions</td><td><b><i><?php echo implode(', ', get_loaded_extensions()); ?></i></b></td></tr>
					<tr class="wpsh-sect-0" style="display:none"><td>WordPress</td><td><b><?php echo $wp_version; ?></b></td></tr>
					<tr><td>Language</td><td><b><?php echo WPLANG; ?></b></td></tr>
					<tr><td>Memory Limit</td><td><b><?php echo size_format($this->boot_loader->memory_limit); ?></b></td></tr>
					<tr><td><b>Checkpoints:</b></td>
						<td>
							<a class="wpsh-toggle-section" id="wpsh-sect-memory" href="#wpsh-checkpoint"><span>Details &raquo;</span><span style="display:none">&laquo; Simple</span></a>
						</td>
					</tr>
					<?php foreach($this->boot_loader->check_points as $checkpoint) $this->_echo_checkpoint_row($checkpoint); ?>
				</table>			
			</div>
			<div id="wpsh-php" class="ui-tabs-hide">
				<table width="100%" class="fixed widefat" cellspacing="8px"  style="border-style: none;">
					<tr><td width="160px;"><b>Runtime Configuration:</b></td>
						<td><a class="wpsh-toggle-section" id="wpsh-sect-1" href="#wpsh-checkpoint"><span>Details &raquo;</span><span style="display:none">&laquo; Simple</span></a></td>
					</tr>
					<tr class="wpsh-sect-1" style="display:none"><td>Include Path<br/><small><i>(include_path)</i></small></td><td><b><?php echo ini_get('include_path'); ?></b><br/><small>Specifies a list of directories where the require(), include(), fopen(), file(), readfile() and file_get_contents()  functions look for files.</br></td></tr>										
					<tr class="wpsh-sect-1" style="display:none"><td>Maximum Input Time<br/><small><i>(max_input_time)</i></small></td><td><b><?php echo ini_get('max_input_time'); ?> seconds</b><br/><small>This sets the maximum time in seconds a script is allowed to parse input data, like POST, GET and file uploads. </br></td></tr>					
					<tr><td>Maximum Execution Time<br/><small><i>(max_execution_time)</i></small></td><td><b><?php $et = ini_get('max_execution_time'); if ($et > 1000) $et /= 1000; echo $et; ?> seconds</b><br/><small>This sets the maximum time in seconds a script is allowed to run before it is terminated by the parser.</br></td></tr>

					<tr><td width="150px;"><b>File Upload Settings:</b></td>
						<td><a class="wpsh-toggle-section" id="wpsh-sect-2" href="#wpsh-checkpoint"><span>Details &raquo;</span><span style="display:none">&laquo; Simple</span></a></td>
					</tr>
					<tr class="wpsh-sect-2" style="display:none"><td>HTTP File Upload<br/><small><i>(file_uploads)</i></small></td><td><b><?php echo $this->boot_loader->convert_ini_bool(ini_get('file_uploads')); ?></b><br/><small>Whether or not to allow HTTP file uploads.</br></td></tr>
					<tr class="wpsh-sect-2" style="display:none"><td>Temporary Directory<br/><small><i>(upload_tmp_dir)</i></small></td><td><b><?php echo ini_get('upload_tmp_dir'); ?></b><br/><small>The temporary directory used for storing files when doing file upload.</br></td></tr>
					<tr><td>Maximum File Size<br/><small><i>(upload_max_filesize)</i></small></td><td><b>
						<?php echo size_format($this->boot_loader->convert_ini_bytes(ini_get('upload_max_filesize'))); ?></b><br/><small>The maximum size of an uploaded file</small>
					</td></tr>
					
					<tr><td width="150px;"><b>Data handling:</b></td>
						<td><a class="wpsh-toggle-section" id="wpsh-sect-3" href="#wpsh-checkpoint"><span>Details &raquo;</span><span style="display:none">&laquo; Simple</span></a></td>
					</tr>
					<tr class="wpsh-sect-3" style="display:none"><td>Maximum Post Size<br/><small><i>(post_max_size)</i></small></td><td><b><?php echo size_format($this->boot_loader->convert_ini_bytes(ini_get('post_max_size'))); ?></b><br/><small>Sets max size of post data allowed. This setting also affects file upload. To upload large files, this value must be larger than upload_max_filesize.   If memory limit is enabled by your configure script, memory_limit also affects file uploading. Generally speaking, memory_limit should be larger than post_max_size.</br></td></tr>
					<tr class="wpsh-sect-3" style="display:none"><td>Multibyte Function Overload<br/><small><i>(mbstring.func_overload)</i></small></td><td><b><?php echo ini_get('mbstring.func_overload'); ?></b><br/><small>Overloads a set of single byte functions by the mbstring counterparts.</br></td></tr>

					<tr><td width="150px;"><b>Language Options:</b></td>
						<td><a class="wpsh-toggle-section" id="wpsh-sect-4" href="#wpsh-checkpoint"><span>Details &raquo;</span><span style="display:none">&laquo; Simple</span></a></td>
					</tr>
					<tr><td>Short Open Tags<br/><small><i>(short_open_tag)</i></small></td><td><b><?php echo $this->boot_loader->convert_ini_bool(ini_get('short_open_tag')); ?></b><br/><small>Tells whether the short form (&lt;? ?&gt;) of PHP's open tag should be allowed.</br></td></tr>
					<tr class="wpsh-sect-4" style="display:none"><td>ASP Tags<br/><small><i>(asp_tags)</i></small></td><td><b><?php echo $this->boot_loader->convert_ini_bool(ini_get('asp_tags')); ?></b><br/><small>Enables the use of ASP-like &lt;% %&gt; tags in addition to the usual &lt;?php ?&gt; tags.</br></td></tr>					
					<tr class="wpsh-sect-4" style="display:none"><td>Zend Engine Compatibitlity<br/><small><i>(zend.ze1_compatibility_mode)</i></small></td><td><b><?php echo $this->boot_loader->convert_ini_bool(ini_get('zend.ze1_compatibility_mode')); ?></b><br/><small>Enable compatibility mode with Zend Engine 1 (PHP&nbsp;4).</br></td></tr>					
										
					<tr><td width="150px;"><b>Security and Safe Mode:</b></td>
						<td><a class="wpsh-toggle-section" id="wpsh-sect-5" href="#wpsh-checkpoint"><span>Details &raquo;</span><span style="display:none">&laquo; Simple</span></a></td>
					</tr>
					<tr><td>Remote open Files<br/><small><i>(allow_url_fopen)</i></small></td><td><b><?php echo $this->boot_loader->convert_ini_bool(ini_get('allow_url_fopen')); ?></b><br/><small>This option enables the URL-aware fopen wrappers that enable accessing URL object like files. Should be disabled for security reasons, to prevent remote file inclusion attacks.</br></td></tr>
					<tr class="wpsh-sect-5" style="display:none"><td>Remote include Files<br/><small><i>(allow_url_include)</i></small></td><td><b><?php echo $this->boot_loader->convert_ini_bool(ini_get('allow_url_include')); ?></b><br/><small>This option allows the use of URL-aware fopen wrappers with the following functions: include(), include_once(), require(), require_once(). Should be disabled for security reasons, to prevent remote file inclusion attacks.</br></td></tr>					
					<tr><td>PHP Safe Mode<br/><small><i>(safe_mode)</i></small></td><td><b><?php echo $this->boot_loader->convert_ini_bool(ini_get('safe_mode')); ?></b><br/><small>Whether to enable PHP's safe mode.</br></td></tr>
					<tr><td>Open Basedir<br/><small><i>(open_basedir)</i></small></td><td><b><?php echo ini_get('open_basedir'); ?></b><br/><small>Limit the files that can be opened by PHP to the specified directory-tree, including the file itself. This directive is NOT affected by whether Safe Mode is turned On or Off.</br></td></tr>
					<tr class="wpsh-sect-5" style="display:none"><td>Disabled Function<br/><small><i>(disable_functions)</i></small></td><td><b><?php echo ini_get('disable_functions'); ?></b><br/><small>This directive allows you to disable certain functions for security reasons.</br></td></tr>					
					<tr class="wpsh-sect-5" style="display:none"><td>Disabled Classes<br/><small><i>(disable_classes)</i></small></td><td><b><?php echo ini_get('disable_classes'); ?></b><br/><small>This directive allows you to disable certain classes for security reasons.</br></td></tr>
					
				</table>						
			</div>
			<div id="wpsh-wordpress" class="ui-tabs-hide">
				<table width="100%" class="fixed widefat" cellspacing="8px"  style="border-style: none;">
					<tr><td width="160px;"><b>HTTP Transport:</b></td>
						<td><a class="wpsh-toggle-section" id="wpsh-sect-6" href="#wpsh-checkpoint"><span>Details &raquo;</span><span style="display:none">&laquo; Simple</span></a></td>
					</tr>
					<?php foreach ( $this->transports_available as $transport => $data ) : ?>
						<tr class="wpsh-sect-6" style="display:none"><td><?php echo $data['name']; ?><br/><small><i>(<?php echo $transport; ?>)</i></small></td><td><b><?php echo ($data['use'] ? 'Yes' :  'No'); ?></b><br/><small><?php echo $data['desc']; ?></br></td></tr>
					<?php endforeach; ?>
				
					<tr><td width="160px;"><b>System Constants:</b></td>
						<td><a class="wpsh-toggle-section" id="wpsh-sect-7" href="#wpsh-checkpoint"><span>Details &raquo;</span><span style="display:none">&laquo; Simple</span></a></td>
					</tr>
					<tr><td>Post Revision Handling<br/><small><i>(WP_POST_REVISIONS)</i></small></td>
						<td><b><?php 
							$state = '-n.a.-';
							if ((WP_POST_REVISIONS === false) || (WP_POST_REVISIONS === 0)) {
								$state = 'Off';
							}elseif ((WP_POST_REVISIONS === true) || (WP_POST_REVISIONS === -1)) {
								$state = 'no limit';
							}
							else {
								$state = WP_POST_REVISIONS;
							}
							echo $state; ?></b><br/><small>Whether to skip, enable or limit post revisions.</br>
						</td>
					</tr>
					<tr>
						<td>Automatic Save Interval<br/><small><i>(AUTOSAVE_INTERVAL)</i></small></td>
						<td><b><?php echo (AUTOSAVE_INTERVAL == false ? 'Off' : AUTOSAVE_INTERVAL.' seconds'); ?></b><br/><small>Post/Page Editor time interval for sending an automatic draft save.</br></td>
					</tr>
					<tr class="wpsh-sect-7" style="display:none"><td>Journal Database Requests<br/><small><i>(SAVEQUERIES)</i></small></td><td><b><?php echo $this->boot_loader->convert_const_bool("SAVEQUERIES"); ?></b><br/><small>Whether to enable journal of database queries performed.</br></td></tr>
					<tr class="wpsh-sect-7" style="display:none"><td>Concatinate Javascripts<br/><small><i>(CONCATENATE_SCRIPTS)</i></small></td><td><b><?php echo $this->boot_loader->convert_const_bool("CONCATENATE_SCRIPTS"); ?></b><br/><small>Whether to enable concatination of all enqueued Javascripts into one single file for serving.</br></td></tr>
					<tr class="wpsh-sect-7" style="display:none"><td>Compress Javascripts<br/><small><i>(COMPRESS_SCRIPTS)</i></small></td><td><b><?php echo $this->boot_loader->convert_const_bool("COMPRESS_SCRIPTS"); ?></b><br/><small>Whether to enable compression of Javascripts being served.</br></td></tr>
					<tr class="wpsh-sect-7" style="display:none"><td>Compress Stylesheets<br/><small><i>(COMPRESS_CSS)</i></small></td><td><b><?php echo $this->boot_loader->convert_const_bool("COMPRESS_CSS"); ?></b><br/><small>Whether to enable compression of Stylesheet files being served.</br></td></tr>
					<tr class="wpsh-sect-7" style="display:none"><td>Enforce GZip Compression<br/><small><i>(ENFORCE_GZIP)</i></small></td><td><b><?php echo $this->boot_loader->convert_const_bool("ENFORCE_GZIP"); ?></b><br/><small>Whether to force GZip instead of Inflate if compression is enabled.</br></td></tr>
				</table>						
			</div>
			<div id="wpsh-database" class="ui-tabs-hide">
				<table width="100%" class="fixed widefat" cellspacing="8px"  style="border-style: none;">
					<tr><td width="160px;"><b>Table Statistics:</b></td>
						<td><a class="wpsh-toggle-section" id="wpsh-sect-8" href="#wpsh-checkpoint"><span>Details &raquo;</span><span style="display:none">&laquo; Simple</span></a></td>
					</tr>
				<?php
					global $wpdb, $table_prefix;
					$tables = array(
						$table_prefix.'comments', 
						$table_prefix.'links', 
						$table_prefix.'options', 
						$table_prefix.'postmeta', 
						$table_prefix.'posts', 
						$table_prefix.'term_relationships', 
						$table_prefix.'term_taxonomy', 
						$table_prefix.'terms', 
						$table_prefix.'usermeta', 
						$table_prefix.'users'
					);
					$res = $wpdb->get_results('SHOW TABLE STATUS');
					$counter = array();
					$db_memory = array('wordpress' => 0, 'custom' => 0 );
					foreach($res as $row) : ?>
							<tr<?php if ($row->Name != $table_prefix.'posts') echo  ' class="wpsh-sect-8" style="display:none"'; ?>>
								<?php if (in_array($row->Name, $tables)) : $db_memory['wordpress'] += ($row->Data_length + $row->Index_length + $row->Data_free); ?>
								<td><?php echo $row->Name; $counter[$row->Name] = $row->Rows; ?><br/><small><i>(<?php echo $row->Engine; ?> | WordPress)</i></small></td>
								<?php else : $db_memory['custom'] += $row->Data_length + $row->Index_length + $row->Data_free; ?>
								<td><?php echo $row->Name; $counter[$row->Name] = $row->Rows; ?><br/><small><i>(<?php echo $row->Engine; ?> | Custom)</i></small></td>
								<?php endif; ?>
								<td>
									<b><?php echo $row->Rows.' rows'; ?></b><br/>
									<i>Data: </i><?php echo ($row->Data_length == 0 ? '0 B' : size_format($row->Data_length,2)); ?><br/> 
									<i>Index: </i><?php echo ($row->Index_length == 0 ? '0 B' : size_format($row->Index_length,2)); ?><br/> 
									<i>Waste: </i><?php echo ($row->Data_free == 0 ? '0 B' : size_format($row->Data_free,2)); ?><br/>
								</td>
							</tr>	
					<?php endforeach; ?>
					
					<tr><td width="160px;"><b>Utilization Summary:</b></td>
						<td><a class="wpsh-toggle-section" id="wpsh-sect-9" href="#wpsh-checkpoint"><span>Details &raquo;</span><span style="display:none">&laquo; Simple</span></a></td>
					</tr>
					<tr class="wpsh-sect-9" style="display:none"><td>WordPress Tables<br/><small><i>(memory usage)</i></small></td><td><b><?php echo size_format($db_memory['wordpress'], 3) ?></b><br/><small>Amount of memory your WordPress tables currently utilize.</br></td></tr>
					<tr class="wpsh-sect-9" style="display:none"><td>Custom/Plugin Tables<br/><small><i>(memory usage)</i></small></td><td><b><?php echo size_format($db_memory['custom'], 3) ?></b><br/><small>Amount of memory your Custom tables currently utilize.</br></td></tr>
					<tr><td>Utilization Total<br/><small><i>(memory usage)</i></small></td><td><b><?php echo size_format($db_memory['wordpress'] + $db_memory['custom'], 3) ?></b><br/><small>Amount of memory your database currently utilize in total.</br></td></tr>
					
					<tr><td width="160px;"><b><i>Posts</i> Table Analysis:</b></td>
						<td><a class="wpsh-toggle-section" id="wpsh-sect-10" href="#wpsh-checkpoint"><span>Details &raquo;</span><span style="display:none">&laquo; Simple</span></a></td>
					</tr>
					<?php 
					$res = $wpdb->get_results('SELECT post_type, COUNT(post_type) as entries FROM '.$table_prefix.'posts GROUP BY post_type');
					$total = $counter[$table_prefix.'posts'];
					foreach($res as $row) { ?>
						<tr<?php if ($row->post_type != 'post') echo  ' class="wpsh-sect-10" style="display:none"'; ?>>
							<td><?php echo $row->post_type; ?><br/><small><i>(Type)</i></small></td>
							<td>
							<?php 
								$perc = round(($total != 0 ? $row->entries * 100.0 / $total: 0), 2);
								if ($row->post_type == 'revision') {
									$this->_echo_progress_bar($perc, $row->entries." rows", 'percentage of total rows', 50, 70);
								}else{
									$this->_echo_progress_bar($perc, $row->entries." rows", 'percentage of total rows', 100, 100);
								}
							?>
							</td>
						</tr>
					<?php
					}
				?>
				</table>						
			</div>
		</div>
		<script type="text/javascript">
		//<![CDATA[
		jQuery(document).ready( function($) {
			//jQuery UI 1.5.2 doesnt expect tab IDs at DIV, so we have to apply a hotfix instead
			var needs_jquery_hotfix = (($.ui.version === undefined) || !$.ui.version.match(/^(1\.[7-9]|[2-9]\.)/));
			$("#wpsh-tabs"+(needs_jquery_hotfix ? ">ul" : "")).tabs({
				selected: 0
			}); 
			//because of jQuery 1.3.2 IE8 bug: http://dev.jquery.com/ticket/4661  we can't use toggle at them moment
			//IE 8 doesn't evaluate is(':visible') and also is(':hidden'), so the toggle() function doesn't work !!! 
			$('.wpsh-toggle-section').click(function() {
				//additionally the jQuery 1.2.6 has an other bug related to table displayment also worked around !!!
				if (!needs_jquery_hotfix) {
					$(this).find('span').each(function(i, elem) {
						$(elem).toggle($(elem).css('display') == 'none');
					});
					$('.'+$(this).attr('id')).each(function(i, elem) {
						$(elem).toggle($(elem).css('display') == 'none');
					});
				}else {
					/* this works in all browser except IE 8 at jQuery 1.3.2 and seems to affect Safari 4 too. 
					$(this).find('span').toggle();
					$('.'+$(this).attr('id')).toggle();
					*/
					$(this).find('span').each(function(i, elem) {
						$(elem).css('display') == 'none' ? $(elem).css('display', 'table-row') : $(elem).hide();
					});
					$('.'+$(this).attr('id')).each(function(i, elem) {
						$(elem).css('display') == 'none' ? $(elem).css('display', 'table-row') : $(elem).hide();
					});
				}
				return false;
			});
			$('.wpsh-sect-memory:last').show().removeClass('wpsh-sect-memory');
		});
		//]]>
		</script>
		<?php
	}
}

$wpsh_plugin = new wpsh_plugin();

?>